ownCloud App for authenticating users against privacyIDEA
=========================================================

Installation
------------

Copy the directory *user_privacyidea* to the ownCloud directory *apps/*.
Then you can activate this app. After activating the app you also need to
configure it.

Configuration
-------------

``privacyIDEA URL``. this is the URL of the privacyIDEA server. It should be
something like "https://your.own.server/".

``Verify SSL certificate``. If this is checked, the SSL certificate is
verified if it is valid.

``User privacyIDEA to authenticate users``. If you enable this, users will be
authenticated against privacyIDEA. As long as this is not checked, nothing
changes.

